@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:DERIV';    # AUTHORITY
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 use feature qw(state);
 use parent  qw(Log::Any::Adapter::Coderef);
@@ -348,8 +348,11 @@ sub log_entry {
         message  => $data->{message},
         severity => $data->{severity},
     );
+
     if ($self->{context} && ref($self->{context}) eq 'HASH') {
-        foreach my $key (keys %{$self->{context}}) {
+        my @keys = keys %{$self->{context}};    # Get the keys from the context hash
+
+        foreach my $key (@keys) {
             $log_data{$key} = $self->{context}->{$key};
         }
         my $json_string = $JSON->encode(\%log_data);
